==> aiobungie-0.2.11.tar.gz: aiobungie-0.2.11/aiobungie/metadata.py <==
# MIT License
#
# Copyright (c) 2020 - Present nxtlo
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Information about aiobungie"""

# This is only used to avoid circular imports errors.

__all__ = (
    "__version__",
    "__about__",
    "__author__",
    "__docs__",
    "__license__",
    "__url__",
    "__email__",
)

import typing

__version__: typing.Final[str] = "0.2.11"
__about__: typing.Final[
    str
] = "A statically typed, asynchronous API wrapper for building clients for Bungie's API in Python."
__author__: typing.Final[str] = "nxtlo"
__docs__: typing.Final[str] = "https://nxtlo.github.io/aiobungie/"
__license__: typing.Final[str] = "MIT"
__url__: typing.Final[str] = "https://github.com/nxtlo/aiobungie"
__email__: typing.Final[str] = "dhmony-99@hotmail.com"

==> aiobungie-0.3.0.tar.gz: aiobungie-0.3.0/aiobungie/metadata.py <==
# MIT License
#
# Copyright (c) 2020 - Present nxtlo
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Information about aiobungie"""

# This is only used to avoid circular imports errors.

__all__ = (
    "__version__",
    "__about__",
    "__author__",
    "__docs__",
    "__license__",
    "__url__",
    "__email__",
)

import typing

__version__: typing.Final[str] = "0.3.0"
__about__: typing.Final[str] = (
    "A statically typed, asynchronous API wrapper for building clients for Bungie's API in Python."
)
__author__: typing.Final[str] = "nxtlo"
__docs__: typing.Final[str] = "https://nxtlo.github.io/aiobungie/"
__license__: typing.Final[str] = "MIT"
__url__: typing.Final[str] = "https://github.com/nxtlo/aiobungie"
__email__: typing.Final[str] = "dhmony-99@hotmail.com"
